@@ -2,7 +2,7 @@
 
 from .base import (type_assert, convert_into_torch_tensor, convert_into_nparray, assert_and_auto_type)
 
-from .gpu import (get_free_gpu, subprocess, set_cuda_visible_devices)
+from .gpu import (get_free_gpu, set_cuda_visible_devices)
 
 from .path import (is_filepath, check_file_exist, fopen, symlink,
                    scandir, find_vcs_root, mkdir_or_exist)
